@@ -222,7 +222,7 @@ def html_auction(auction, section_auction):
 
 def pbn2html(pbn_file):
     all = {
-        "generated" : "2020-12-01"
+        "generated" : "2021-05-14"
     }
 
     # handle multiple pbn in one file
@@ -276,7 +276,8 @@ def pbn2html(pbn_file):
     src = Template(html_template)
     all = { "all": result, "version": version }
     result = src.safe_substitute(all)
-    output = os.path.splitext(pbn_file)[0]+'.html'
+    # output = os.path.splitext(pbn_file)[0]+'.html'
+    output = pbn_file + '.html'
     with io.open(output, "w", encoding="utf-8") as text_file:
         print("write to file %s" % output)
         text_file.write(result)
